@@ -52,7 +52,7 @@ function displayURL() {
   originURLLink.href = originURL;
 
   openURLButton.addEventListener("click", function() {
-    if (confirm(chrome.i18n.getMessage("chrome_disable_on_this_site") + '?')) {
+    if (confirm(chrome.i18n.getMessage("cancel_open_page") + '?')) {
       sendMessage("disable_on_site", url.host, () => {
         window.location = originURL;
       });
@@ -117,7 +117,7 @@ function displayURL() {
   });
 
   openHttpOnce.addEventListener("click", function() {
-    if (confirm(chrome.i18n.getMessage("chrome_disable_on_this_site") + '?')) {
+    if (confirm(chrome.i18n.getMessage("cancel_http_once") + '?')) {
       sendMessage("disable_on_site_once", url.host, () => {
         window.location = originURL;
       });
